// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @package    theme_hsh_boost_campus
 * @copyright  2018 Tobias Baden, Hochschule Hannover
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


define(["jquery"], function($) {
    function changeActionString(current, wwwroot) {
        let actionString = wwwroot;
        if (current.val() !== 0) {
            actionString += "/course/view.php?id=" + current.val();
        } else {
            actionString += "/my";
        }
        $("#hshcourseform").attr("action", actionString);
    }

    function setInactive(target) {
        target.removeClass("active");
        target.removeClass("activeCourseSearch");
    }

    function setActive(target) {
        target.addClass("active");
        target.addClass("activeCourseSearch");
    }

    function scrollIntoViewIfNeeded(element) {
        var windowSize = window.innerHeight;
        var elementPosition = element.getBoundingClientRect();
        var elementBottom = elementPosition.bottom;
        var elementTop = elementPosition.top;

        if (elementBottom > windowSize) {
            // Scroll an den unteren Rand des Bildes.
            element.scrollIntoView({ block: "end", behavior: "smooth" });
        }
        if (elementTop < 0) {
            // Scroll an den oberen Rand des Bildes.
            element.scrollIntoView({ block: "start", behavior: "smooth" });
        }
    }

    return {
        init: function(wwwroot) {
            $("input").keydown(function(e) {
                var listItems = $(".hshcoursesearchlistitem");
                var selected = listItems.filter(".activeCourseSearch");
                var current;
                var key = e.keyCode;

                if (key !== 40 && key !== 38 && key !== 13) {
                    return;
                }

                setInactive(listItems);

                if (key === 38) {
                    // KEY UP!
                    if (!selected.length || selected.is(":first-child")) {
                        current = listItems.last();
                    } else {
                        current = selected.prev();
                    }
                    changeActionString(current, wwwroot);
                } else if (key === 40) {
                    // KEY DOWN!
                    if (!selected.length || selected.is(":last-child")) {
                        current = listItems.eq(0);
                    } else {
                        current = selected.next();
                    }
                    changeActionString(current, wwwroot);
                } else if (key === 13) {
                    // KEY ENTER!
                    current = selected;
                    if (isNaN(current.val())) {
                        current = listItems.eq(0);
                    }
                    changeActionString(current, wwwroot);
                }

                setActive(current);
                var scrollToElement = document.getElementsByClassName(
                    "activeCourseSearch"
                )[0];
                scrollIntoViewIfNeeded(scrollToElement);
            });
        }
    };
});
